.level_rr_logo {
  text-align: center;
}

.level_rr_logo img {
  width: 25%;
}

.dropdown > .button--secondary,
.row > div > .button--secondary,
.row > div > .button--primary {
  margin: 0;
}

.input--icon > input[type="text"],
.input--icon > input[type="text"]:hover,
.input--icon > input[type="text"]:focus {
  border: 2px solid #eab502;
}

input[type="checkbox"] {
  width: 20px;
}

.open > .dropdown-menu {
  display: flex;
  flex-direction: column;
}

.button--dropdown,
.dropdown-menu {
  width: 100%;
  background-color: #fff;
}

.dropdown-menu {
  overflow-x: hidden;
  font-style: normal;
  max-height: 380px;
}

.dropdown-menu > ul {
  font-style: normal;
  overflow-y: auto;
}

.dropdown-menu > .row {
  padding: 15px 0 15px 0;
}

.dropdown-menu__option__text {
  width: 100%;
}

.dropdown-menu__option__text label {
  align-items: center;
  display: flex;
  flex-direction: row-reverse;
  font-weight: normal;
  justify-content: space-between;
  margin: 0;
}

.tableWrapper {
  width: 100%;
}

div.DTFC_LeftBodyLiner,
div.DTFC_RightBodyLiner {
  overflow: hidden;
}

.dataTables_wrapper .dataTables_length,
.dataTables_wrapper .dataTables_filter,
.dataTables_wrapper .dataTables_paginate span,
.dataTables_wrapper .dataTables_paginate .disabled,
.dataTables_wrapper .dataTables_paginate .paginate_button.disabled {
  display: none;
}

a.next:focus,
a.previous:focus {
  outline: none;
}

#scoreboardTable_wrapper table,
#scoreboardTable_wrapper th,
#scoreboardTable_wrapper td,
#improvementTable_wrapper table,
#improvementTable_wrapper th,
#improvementTable_wrapper td {
  border: none;
  border-right: 1px solid white;
}

table {
  width: 99%;
}

table tbody td {
  font-size: 15px;
}

table th.fixed-width,
table td.fixed-width {
  max-width: 140px;
  min-width: 140px;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
}

#scoreboardTable_wrapper td.scoreboard--started {
  background: #e0004d;
  color: white;
}

#scoreboardTable_wrapper td.scoreboard--completed {
  color: #eab502;
  font-size: 24px;
}

#scoreboardTable_wrapper td.scoreboard--completed-secondary {
  color: #fff;
  font-size: 24px;
}

#scoreboardTable_wrapper td.scoreboard--medium-performer {
  background: #f6a500;
}

#scoreboardTable_wrapper td.scoreboard--top-performer {
  background: #b1ba1d;
}

#scoreboardTable_wrapper tr.current-student > td {
  background: #85ddff; /* $color-tertiary-50 */
}
